@@ -43,7 +43,10 @@ class ClientModel(ABC):
         elif _dict:
             self.dict.update(_dict)
         for key in ignored_list:
-            self.__delitem__(key)
+            try:
+                self.__delitem__(key)
+            except KeyError:
+                pass
         self.validate()
 
     def __getitem__(self, key):
