@@ -104,8 +104,8 @@ CLIENT = CacheClient(
     "{cache_file_name}",
     author="Renas Mirkan Kilic",
     plugin_version="1",
-    date_created="{special_strftime()}"
-    ignored_list=["database", "query", "this_plugin_name"]
+    date_created="{special_strftime()}",
+    ignored_list=["query", "this_plugin_name"]
 )
 
 def metric_collector():
